fn connects_to(
world: &dyn LevelReader,
neighbor_state: BlockStateId,
neighbor_pos: BlockPos,
direction: Direction,
) -> boolExpand description
Checks if this bar should connect to the given neighbor state.
fn connects_to(
world: &dyn LevelReader,
neighbor_state: BlockStateId,
neighbor_pos: BlockPos,
direction: Direction,
) -> boolChecks if this bar should connect to the given neighbor state.