pub fn get_connection_state(
block: BlockRef,
world: &World,
pos: &BlockPos,
) -> BlockStateIdExpand description
Gets the connection state for a position by checking all 4 horizontal neighbors.
pub fn get_connection_state(
block: BlockRef,
world: &World,
pos: &BlockPos,
) -> BlockStateIdGets the connection state for a position by checking all 4 horizontal neighbors.